/*
 * Copyright (c) 2005 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

#ifdef __ppc__

#include <string.h>
#include <mach-o/dyld.h>

__private_extern__ void *
__stub_getrealaddr(const char *root)
{
    char *cp;
    char name[64];
    NSSymbol sym;

    name[0] = '_';
    strcpy(name + 1, root);
    cp = name + strlen(name);
    strcpy(cp, "$LDBL128");
    if (!NSIsSymbolNameDefinedWithHint (name, "libSystem."))
	*cp = 0;

    sym = NSLookupAndBindSymbolWithHint (name, "libSystem.");
    return (void *)NSAddressOfSymbol (sym);
}

#endif
